#
# spec file for package python-google-cloud-speech
#
# Copyright (c) 2025 SUSE LLC
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


%{?sle15_python_module_pythons}
Name:           python-google-cloud-speech
Version:        2.32.0
Release:        1.1
Summary:        Google Cloud Speech API client library
License:        Apache-2.0
Group:          Development/Languages/Python
URL:            https://github.com/googleapis/google-cloud-python
Source:         https://files.pythonhosted.org/packages/source/g/google-cloud-speech/google_cloud_speech-%{version}.tar.gz
BuildRequires:  %{python_module google-api-core >= 1.34.1}
BuildRequires:  %{python_module pip}
BuildRequires:  %{python_module proto-plus >= 1.22.3}
BuildRequires:  %{python_module protobuf >= 3.20.2}
BuildRequires:  %{python_module pytest-asyncio}
BuildRequires:  %{python_module pytest}
BuildRequires:  %{python_module wheel}
BuildRequires:  fdupes
BuildRequires:  python-rpm-macros
Requires:       python-google-api-core >= 1.34.1
Requires:       python-google-auth
Requires:       python-proto-plus >= 1.22.3
Requires:       python-protobuf >= 3.20.2
BuildArch:      noarch
%python_subpackages

%description
Cloud Speech API converts audio to text by applying neural network models.

%prep
%autosetup -p1 -n google_cloud_speech-%{version}
# remove tests needing credentials to google services
#rm tests/system/gapic/v1/test_system_speech_v1.py
#rm tests/system/gapic/v1p1beta1/test_system_speech_v1p1beta1.py

%build
%pyproject_wheel

%install
%pyproject_install
%python_expand %fdupes %{buildroot}%{$python_sitelib}

%check
%pytest -k "not test_list_phrase_set"

%files %{python_files}
%exclude %{_bindir}/*.py
%license LICENSE
%doc README.rst
%{python_sitelib}/google/cloud/speech
%{python_sitelib}/google/cloud/speech_v1*
%{python_sitelib}/google/cloud/speech_v2
%{python_sitelib}/google_cloud_speech-%{version}.dist-info

%changelog
* Sat Apr 26 2025 John Paul Adrian Glaubitz <adrian.glaubitz@suse.com>
- Update to 2.32.0
  * Add ALAW support to RecognitionConfig
  * Add new fields to CustomClass and PhraseSet.Phrase messages
  * Deprecating speaker_tag (int) for speaker_label (string)
  * Make transcript_normalization field optional
  * Miscellaneous clarifications
- from version 2.31.1
  * [Many APIs] Allow Protobuf 6.x
  * Remove setup.cfg configuration for creating universal wheels (#13659)
- from version 2.31.0
  * Add REST Interceptors which support reading metadata
  * Add support for reading selective GAPIC generation methods from service YAML
- from version 2.30.0
  * Expand the set of supported explicit audio encodings
  * Updated ExplicitDecodingConfig documentation to reflect
    changes related to newly supported encodings
- from version 2.29.0
  * Add support for opt-in debug logging
  * Fix typing issue with gRPC metadata when key ends in -bin
- from version 2.28.1
  * Disable universe-domain validation (#13246)
- Update BuildRequires and Requires from setup.py
* Tue Oct 29 2024 Dirk Müller <dmueller@suse.com>
- update to 2.28.0:
  * Add support for Python 3.13
  * add locations metadata proto file
  * Retry and timeout values do not propagate in requests during
    pagination
  * update the list of automatically detected encodings
  * update the maximum number of files that may be included in a
    BatchRecognizeRequest
* Sat Apr 20 2024 Dirk Müller <dmueller@suse.com>
- update to 2.26.0:
  * add translation_config in RecognitionConfig message
  * add API for writing BatchRecognize transcripts in SRT and VTT formats
  * Require google-api-core>=1.34.1
  * fix ValueError in test__validate_universe_domain
  * Add google-auth as a direct dependency
  * Add staticmethod decorator to _get_client_cert_source and
    _get_api_endpoint
  * Resolve AttributeError 'Credentials' object has no attribute
    'universe_domain'
* Sun Feb  4 2024 Dirk Müller <dmueller@suse.com>
- update to 2.24.0:
  * Allow users to explicitly configure universe domain
* Sat Dec 16 2023 Dirk Müller <dmueller@suse.com>
- update to 2.23.0:
  * Add support for python 3.12
  * Introduce compatibility with native namespace packages
  * Require proto-plus >= 1.22.3 (e9655df)
  * Use retry_async instead of retry in async client
* Wed Dec  6 2023 John Paul Adrian Glaubitz <adrian.glaubitz@suse.com>
- Update to 2.22.0
  * Add transcript normalization + m4a audio format support (8536b20)
  * Support MP3, TranscriptNormalization and SpeakerLabels in STT V1 API (#11967)
  * Clarify alternatives for deprecated fields (8536b20)
  * Deprecate `BatchRecognizeFileResult.transcript` in favor of
    `inline_result.transcript` (8536b20)
  * Deprecate `BatchRecognizeFileResult.uri` in favor of
    `cloud_storage_result.native_format_uri` (8536b20)
- Drop patches for issues fixed upstream
  * python-google-cloud-speech-no-mock.patch
- Skip tests that are currently failing
  * test_list_phrase_set
* Tue Jul 18 2023 John Paul Adrian Glaubitz <adrian.glaubitz@suse.com>
- Update to 2.21.0
  * Add `model` and `language_codes` fields in `RecognitionConfig`
    message + enable default `_` recognizer (#524)
- from version 2.20.1
  * Add async context manager return types (#522)
* Tue Jun 20 2023 John Paul Adrian Glaubitz <adrian.glaubitz@suse.com>
- Update to 2.20.0
  * **v2:** Add processing strategy to batch recognition requests (#514)
- Refresh patches for new version
  * python-google-cloud-speech-no-mock.patch
* Thu Mar 30 2023 John Paul Adrian Glaubitz <adrian.glaubitz@suse.com>
- Update to 2.19.0
  * Add support for BatchRecognize (2e7ee2d)
  * Fix formatting of request arg in docstring (#512)
  * Fix the resource name format in comment for CreatePhraseSetRequest (2e7ee2d)
- from version 2.18.0
  * Enable "rest" transport in Python for services supporting numeric enums (a20d0f1)
  * Voice Activity Detection - adding speech event time and speech event type (a20d0f1)
- from version 2.17.3
  * **v1:** Clarified boost usage (#491)
- from version 2.17.2
  * Clarify boost usage in Reference (#486)
- from version 2.17.1
  * Add context manager return types (ed80330)
  * Add documentation for enums (ed80330)
- from version 2.17.0
  * Add support for python 3.11 (#478)
  * Add typing to proto.Message based class attributes (c2a079c)
  * Added new fields to facilitate debugging (c2a079c)
  * **v1:** Added ABNF Grammars field in Speech Adaptation (ca28974)
  * **v1p1beta1:** Added ABNF Grammars field in Speech Adaptation (ca28974)
  * Add dict typing for client_options (c2a079c)
  * **deps:** Require google-api-core >=1.34.0, >=2.11.0 (c2a079c)
  * Drop usage of pkg_resources (c2a079c)
  * Fix timeout default values (c2a079c)
  * **samples:** Code samples for Speech-to-Text V2 (5c99f00)
  * **samples:** Snippetgen handling of repeated enum field (c2a079c)
  * **samples:** Snippetgen should call await on the operation coroutine
    before calling result (c2a079c)
  * **samples:** Update code samples for adaptation and VAD (#462)
- Update BuildRequires and Requires from setup.py
* Fri Oct 14 2022 John Paul Adrian Glaubitz <adrian.glaubitz@suse.com>
- Update to 2.16.2
  * **deps:** Allow protobuf 3.19.5 (#456)
  * **samples:** Add create_recognizer code sample (#450)
  * **samples:** Add quickstart code sample for STT V2 (#451)
- from version 2.16.1
  * Remove SpeechHelpers from STT V2 client library (#452)
- from version 2.16.0
  * Added Speech-to-Text V2 API (#447)
  * **deps:** Require protobuf >= 3.20.2 (#446)
* Tue Sep 13 2022 John Paul Adrian Glaubitz <adrian.glaubitz@suse.com>
- Update to 2.15.1
  * **deps:** allow protobuf < 5.0.0 (#425)
  * **deps:** require proto-plus >= 1.22.0 (1ad5df9)
- from version 2.15.0
  * add audience parameter (068f8e8)
  * **deps:** require google-api-core>=1.32.0,>=2.8.0 (#416)
  * require python 3.7+ (#414)
- Update BuildRequires and Requires from setup.py
* Thu Jun  9 2022 pgajdos@suse.com
- version update to 2.14.1
  [#]# [2.14.1]
  * **deps:** require protobuf <4.0.0dev
  * fix changelog header to consistent size
  * **samples:** resolve library deprecation warnings
  [#]# [2.14.0]
  * Add adaptation proto for v1 api
  * Add documentation for latest models to RecognitionConfig
  * Update client libraries for v1p1beta1 api
  * update docstrings to use absolute links
- do not require python-mock for build
- added patches
  fix https://github.com/googleapis/python-speech/issues/406
  + python-google-cloud-speech-no-mock.patch
* Thu Apr  7 2022 John Paul Adrian Glaubitz <adrian.glaubitz@suse.com>
- Update to 2.13.1
  Bug Fixes
  * **deps:** require google-api-core>=1.31.5, >=2.3.2 (#334)
  * **deps:** require proto-plus>=1.15.0 (b35bd09)
- from version 2.13.0
  Features
  * add api key support (#313)
  Bug Fixes
  * **deps:** move libcst to extras (#322)
  * resolve DuplicateCredentialArgs error when using credentials_file (#318)
  Documentation
  * add generated snippets (#321)
- from version 2.12.0
  Features
  * add hint boost in SpeechContext (3fdef1f)
  * add result_end_time to SpeechRecognitionResult (#291)
  * add SpeechAdaptation configuration (3fdef1f)
  * add spoken punctuation and spoken emojis (3fdef1f)
  * add WEBM_OPUS codec (3fdef1f)
  * add word confidence (3fdef1f)
  * added alternative_language_codes to RecognitionConfig (#290)
- from version 2.11.1
  Bug Fixes
  * **deps:** drop packaging dependency (43f25c0)
  * **deps:** require google-api-core >= 1.28.0 (43f25c0)
  Documentation
  * list oneofs in docstring (43f25c0)
- from version 2.11.0
  Features
  * add support for python 3.10 (#274)
- from version 2.10.0
  Features
  * add context manager support in client (#268)
- from version 2.9.3
  Documentation
  * **samples:** Remove reference to deprecated message "diarization_speaker_count"
    in favor of diarization_config (#264)
- from version 2.9.2
  Bug Fixes
  * improper types in pagers generation (a0bac07)
- from version 2.9.1
  Bug Fixes
  * add 'dict' annotation type to 'request' (e75ada8)
- from version 2.9.0
  Features
  * add output_config request field (#252)
  Documentation
  * **samples:** fixed model adaptation sample to correctly refer to custom classes (#246)
- from version 2.8.0
  Features
  * Add transcript normalization (#235)
  Documentation
  * **samples:** remove io dependency in transcribe samples (#223)
- from version 2.7.0
  Features
  * add total_billed_time response field (#224)
- from version 2.6.0
  Features
  * **v1p1beta1:** add total_billed_time response field (#219)
  Bug Fixes
  * enable self signed jwt for grpc (#217)
  * **v1p1beta1:** custom_class_id is required field in CreateCustomClassRequest. (e7efa67)
  * **v1p1beta1:** phrase_set_id is required field in CreatePhraseSetRequest (e7efa67)
  Documentation
  * **samples:** Add Spoken Punctuation and Emojis code samples (#155)
  * add Samples section to CONTRIBUTING.rst (#211)
- from version 2.5.1
  Bug Fixes
  * **deps:** pin 'google-{api,cloud}-core', 'google-auth' to allow 2.x versions (#210)
- from version 2.5.0
  Features
  * add always_use_jwt_access (#191)
- from version 2.4.1
  Documentation
  * omit mention of Python 2.7 in 'CONTRIBUTING.rst' (#1127)
- from version 2.4.0
  Features
  * add webm opus support (eb360ae)
  * support self-signed JWT flow for service accounts (eb360ae)
  Bug Fixes
  * add async client to %%name_%%version/init.py (eb360ae)
- from version 2.3.0
  Features
  * Support for spoken punctuation and spoken emojis (#143)
- from version 2.2.1
  Bug Fixes
  * use correct retry deadline (#134)
- from version 2.2.0
  Features
  * adds model adaptation sample (#121)
  * Support output transcript to Google Cloud Storage for LongRunningRecognize (#128)
- from version 2.1.0
  Features
  * add common resource helpers; expose transport; remove gRPC send/recv limits (#100)
  * add from_service_account_info factory (3bed0b4)
  * adds new multi region sample (#96)
  * **v1p1beta1:** support Model Adaptation (#104)
  Bug Fixes
  * Remove incorrect comment on enhanced models (#95)
  Documentation
  * fix sphinx identifiers (3bed0b4)
  * updated setup documentation to point to python-speech instead of python-docs-samples (#89)
- from version 2.0.1
  Bug Fixes
  * deleted a line duplicating the call to the recognizer  (#83)
  * migrated samples to speech 2.0.0 (#78)
- from version 2.0.0
  BREAKING CHANGES
  * migrate to microgenerator (#61)
  Features
  * Migrate to microgenerator (#61)
  Documentation
  * remove example usage from READMe (#46)
- Update BuildRequires and Requires from setup.py
* Wed Apr  8 2020 Marketa Calabkova <mcalabkova@suse.com>
- Update to 1.3.2
  * Add speaker diarization configuration support (via synth).
  * Add SpeakerDiarizationConfig, deprecate enable_speaker_diarization
    and diarization_speaker_count (via synth).
  * Increase timeout values
* Thu Sep 12 2019 Tomáš Chvátal <tchvatal@suse.com>
- Update to 1.2.0:
  * Add 'client_options' support (via synth). (#8534)
  * Increase speech max received msg size to 256 MiB (#8338)
  * Add MP3 to Audio Encoding and add boost to Speech Context (via synth). (#8109)
  * Add Recognition Metadata (via synth). (#7961)
* Tue Mar 26 2019 Tomáš Chvátal <tchvatal@suse.com>
- Update to 1.0.0:
  * Remove unused message exports. (#7275)
  * Promote google-cloud-speech to GA (#7525)
  * Speech: copy lintified proto files (via synth).
  * Add clarifying comment to blacken nox target. (#7404)
  * Copy proto files alongside protoc versions. Remove unneeded utf-8 header.
* Fri Mar 15 2019 Tomáš Chvátal <tchvatal@suse.com>
- Update to 0.36.3:
  * Add 'RecognitionConfig.audio_channel_count' field via synth. (#7240)
  * Protoc-generated serialization update. (#7106)
  * Bump minimum api_core version for all GAPIC libs to 1.4.1. (#6391)
  * Import iam.policy from google.api_core. (#6741)
  * Pick up fixes to GAIPC generator. (#6508)
  * Add result_end_time, docstring changes via synth. (#6462)
  * Assorted synth fixups / cleanups (#6400)
  * Fix client_info bug, update docstrings and timeouts. (#6421)
  * Re-generate library using speech/synth.py (#5979)
- Really execute tests
* Tue Dec  4 2018 Matej Cepl <mcepl@suse.com>
- Remove superfluous devel dependency for noarch package
* Mon Oct 22 2018 Jan Engelhardt <jengelh@inai.de>
- Ensure neutrailty of descriptions.
* Mon Oct 22 2018 Thomas Bechtold <tbechtold@suse.com>
- Initial packaging (version 0.36.0)
